@@ -1,6 +1,6 @@
 
 package Minion::Worker::Role::Kevin;
-$Minion::Worker::Role::Kevin::VERSION = '0.5.4';
+$Minion::Worker::Role::Kevin::VERSION = '0.5.5';
 # ABSTRACT: Alternative Minion worker
 use Mojo::Base -role;
 
@@ -23,16 +23,16 @@ sub _defaults {
   };
 }
 
-sub _build_defaults {
+sub _run_defaults {
   my $self = shift;
-  return {%{$self->_defaults}, %{$self->{defaults} // {}}};
+  $self->{_run_defaults} //= {%{$self->_defaults}, %{$self->{defaults} // {}}};
 }
 
 sub run {
   my ($self, @args) = @_;
 
-  my $status = $self->status;
-  my $defaults = $self->{_defaults} //= $self->_build_defaults;
+  my $status   = $self->status;
+  my $defaults = $self->_run_defaults;
 
   $status->{$_} //= $defaults->{$_} for keys %$defaults;
   $status->{performed} //= 0;
@@ -46,7 +46,8 @@ sub run {
     $status->{repair_interval} -= int rand $status->{repair_interval} / 2;
 
     $self->{next_repair} = $now;
-    $self->{next_repair} += $status->{repair_interval} if delete $status->{fast_start};
+    $self->{next_repair} += $status->{repair_interval}
+      if delete $status->{fast_start};
   }
 
   $self->{pid} = $$;
@@ -77,6 +78,10 @@ sub _term {
   $self->{graceful} = $graceful or kill 'KILL', keys %{$self->{jobs}};
 }
 
+sub _ping {
+  shift->register;
+}
+
 sub _work {
   my $self = shift;
 
@@ -96,7 +101,7 @@ sub _work {
   # Send heartbeats in regular intervals
   if ($status->{heartbeat_interval} && $self->{next_heartbeat} < steady_time) {
     $log->debug('Sending heartbeat') if TRACE;
-    $self->register;
+    $self->_ping;
     $self->{next_heartbeat} = steady_time + $status->{heartbeat_interval};
   }
 
@@ -147,7 +152,7 @@ Minion::Worker::Role::Kevin - Alternative Minion worker
 
 =head1 VERSION
 
-version 0.5.4
+version 0.5.5
 
 =head1 AUTHOR
 
